@@ -71,8 +71,9 @@ trace_calls <- function (x, parent_functions = NULL, parent_ref = NULL) {
     recurse(x)
   }
   else {
-    stop("Unknown language class: ", paste(class(x), collapse = "/"),
+    message("Unknown language class: ", paste(class(x), collapse = "/"),
       call. = FALSE)
+    x
   }
 }
 
