@@ -2,15 +2,15 @@ context("print function")
 test_that("format_percentage works as expected", {
   expect_equal(format_percentage(0), crayon::red("0.00%"))
 
-  expect_equal(format_percentage(0.25), crayon::red("25.00%"))
+  expect_equal(format_percentage(25), crayon::red("25.00%"))
 
-  expect_equal(format_percentage(0.51), crayon::red("51.00%"))
+  expect_equal(format_percentage(51), crayon::red("51.00%"))
 
-  expect_equal(format_percentage(0.765), crayon::yellow("76.50%"))
+  expect_equal(format_percentage(76.5), crayon::yellow("76.50%"))
 
-  expect_equal(format_percentage(0.865), crayon::yellow("86.50%"))
+  expect_equal(format_percentage(86.5), crayon::yellow("86.50%"))
 
-  expect_equal(format_percentage(0.965), crayon::green("96.50%"))
+  expect_equal(format_percentage(96.5), crayon::green("96.50%"))
 })
 
 test_that("print.coverage prints by = \"line\" by default", {
